@@ -79,7 +79,6 @@ extern "C" {
 #include <stdint.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
-#include <unistd.h>
 #endif
 
 #include "request_context.h"
@@ -694,12 +693,12 @@ static struct MHD_Response* handle_catalog(RequestContext* request)
       opdsDumper.setTitle("All zims");
       uuid = zim::Uuid::generate(host);
 
-      bookIdsToDump = library.listBooksIds(
-        kiwix::VALID|kiwix::LOCAL|kiwix::REMOTE);
+      bookIdsToDump = library.filter(kiwix::Filter().valid(true).local(true).remote(true));
     } else if (url == "search") {
       std::string query;
       std::string language;
       std::vector<std::string> tags;
+      std::vector<std::string>  noTags;
       size_t count(10);
       size_t startIndex(0);
       try {
@@ -715,18 +714,20 @@ static struct MHD_Response* handle_catalog(RequestContext* request)
         startIndex = stoul(request->get_argument("start"));
       } catch (...) {}
       try {
-        tags.push_back(request->get_argument("tag"));
+        tags = kiwix::split(request->get_argument("notag"), ";");
+      } catch (...) {}
+      try {
+        noTags = kiwix::split(request->get_argument("notag"), ";");
       } catch (...) {}
       opdsDumper.setTitle("Search result for " + query);
       uuid = zim::Uuid::generate();
-      bookIdsToDump = library.listBooksIds(
-        kiwix::VALID|kiwix::LOCAL|kiwix::REMOTE,
-        kiwix::UNSORTED,
-        query,
-        language,
-        "", // creator
-        "", // publisher
-        tags);
+      bookIdsToDump = library.filter(
+        kiwix::Filter().valid(true).local(true).remote(true)
+          .query(query)
+          .lang(language)
+          .acceptTags(tags)
+          .rejectTags(noTags)
+        );
       auto totalResults = bookIdsToDump.size();
       bookIdsToDump.erase(bookIdsToDump.begin(), bookIdsToDump.begin()+startIndex);
       if (count>0 && bookIdsToDump.size() > count) {
@@ -1118,7 +1119,7 @@ int main(int argc, char** argv)
   }
 
   /* Instance the readers and searcher and build the corresponding maps */
-  vector<string> booksIds = library.listBooksIds(kiwix::LOCAL);
+  vector<string> booksIds = library.filter(kiwix::Filter().local(true));
   globalSearcher = new kiwix::Searcher();
   globalSearcher->setProtocolPrefix(rootLocation + "/");
   globalSearcher->setSearchProtocolPrefix(rootLocation + "/" + "search?");
