@@ -23,6 +23,7 @@
 #define REQUEST_CONTEXT_H
 
 #include <string>
+#include <sstream>
 #include <map>
 #include <stdexcept>
 
@@ -84,7 +85,6 @@ class RequestContext {
     int httpResponseCode;
 
   private:
-    struct MHD_Connection* connection;
     std::string full_url;
     std::string url;
     bool valid_url;
